@@ -8,13 +8,13 @@ ss.checks <- function(x){
   else cat("\nEigenvalue range of the information matrix: [",min(e.v),",",max(e.v),"]\n", sep = "")
 
   if((x$l.sp1!=0 || x$l.sp2!=0) && x$fp==FALSE){
-      cat("\nTrust region iterations before smoothing parameter estimation:",x$iter.if)
+      cat("\nTrust region Newton iterations before smoothing parameter estimation:",x$iter.if)
       cat("\nSmoothing parameter/leapfrog loops:",x$iter.sp)
-      cat("\nTrust region iterations after smoothing parameter/leapfrog step:",x$iter.fi,"\n\n")
+      cat("\nTrust region Newton iterations after smoothing parameter/leapfrog step:",x$iter.fi,"\n\n")
       
 
   }
-  else cat("\nTrust region iterations:",x$iter.if,"\n\n")
+  else cat("\nTrust region Newton iterations:",x$iter.if,"\n\n")
 
 
 }
